menufw/menufwui/mmwidgets/inc/mmcacheforitem.h
branchRCL_3
changeset 9 f966699dea19
parent 4 4d54b72983ae
--- a/menufw/menufwui/mmwidgets/inc/mmcacheforitem.h	Tue Feb 02 00:04:13 2010 +0200
+++ b/menufw/menufwui/mmwidgets/inc/mmcacheforitem.h	Fri Feb 19 22:42:37 2010 +0200
@@ -77,11 +77,14 @@
     inline TBool IsValid() const;
     
     /**
-     * Marks this cache as valid or invalid.
-     * 
-     * @param aValid (Self-explanatory).
-     */
-    inline void SetValidL( TBool aValid );
+	 * Marks this cache object as valid.
+	 */
+    inline void MarkAsValidL();
+    
+    /**
+	 * Marks this cache object as invalid.
+	 */
+    inline void MarkAsInvalid();
     
     /**
      * Returns information whether at the moment of updating this cache object
@@ -249,7 +252,7 @@
     /**
      * Array of icons stored in the icon holders which are in iIconHolderList.
      * This member is only valid when this cache object is marked as valid
      * using the SetValidL method.
      * Own.
      */
     CArrayPtr<CGulIcon>* iIconList;
@@ -249,7 +252,7 @@
      * Array of icons stored in the icon holders which are in iIconHolderList.
      * This member is only valid when this cache object is marked as valid
-     * using the SetValidL method.
+     * using the MarkAsValidL method.
      * Own.
      */